@@ -23,8 +23,8 @@ pub fn app(cx: Scope) -> Element {
                     },
                     None => {},
                 }
-                // info!("{:?}", element_inner_html!(".main"));
-                element_set_inner_html!(".main","<h1>hello</h1>")
+                console_log!(element_inner_html!(".main"));
+                // element_set_inner_html!(".main","<h1>hello</h1>")
             },
             class:"main",
             style{[include_str!("./style/index.css")]},
